@@ -69,9 +69,10 @@ def do_send_message(
                 t_timestamp = t_res.get("result", {}).get("timestamp")
                 if not t_timestamp:
                     logger.error("Unable to read from JSON RPC response: %s", t_res)
-                    return {
-                        "error": "Unable to read response from JSON RPC response"
-                    }, 400
+                    return json(
+                        {"error": "Unable to read response from JSON RPC response"},
+                        400,
+                    )
                 if t_timestamp:
                     search_for = f"[*].{response_method_mapping.get(key, key)}"
                     timestamps.update(
@@ -88,11 +89,11 @@ def do_send_message(
                             }
                         }
                     )
-        return {"timestamps": timestamps}, 201
+        return json({"timestamps": timestamps}, 201)
     # pylint: disable=broad-except
     except Exception:
         logger.error(format_exc())
-        return {"error": "An eror occured. Please check gateway logs."}, 400
+        return json({"error": "An eror occured. Please check gateway logs."}, 400)
     finally:
         for attachment in kwargs.get("attachments", []):
             os_remove(attachment)
